Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1157)

Unified Diff: content/browser/web_contents/navigation_controller_impl.h

Issue 15041004: Replace PruneAllButActive with PruneAllButVisible. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Change to CHECK. Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/web_contents/navigation_controller_impl.h
diff --git a/content/browser/web_contents/navigation_controller_impl.h b/content/browser/web_contents/navigation_controller_impl.h
index 5e50d109c074ee7de230791218a22ca4c2de7fc7..92ee8aff42b931ea10449514535b4031fd6761e1 100644
--- a/content/browser/web_contents/navigation_controller_impl.h
+++ b/content/browser/web_contents/navigation_controller_impl.h
@@ -89,7 +89,8 @@ class CONTENT_EXPORT NavigationControllerImpl
const NavigationController& source) OVERRIDE;
virtual void CopyStateFromAndPrune(
NavigationController* source) OVERRIDE;
- virtual void PruneAllButActive() OVERRIDE;
+ virtual bool CanPruneAllButVisible() OVERRIDE;
+ virtual void PruneAllButVisible() OVERRIDE;
virtual void ClearAllScreenshots() OVERRIDE;
// The session storage namespace that all child RenderViews belonging to
@@ -293,10 +294,11 @@ class CONTENT_EXPORT NavigationControllerImpl
// preparation to add another.
void PruneOldestEntryIfFull();
- // Removes all the entries except the active entry. If there is a new pending
- // navigation it is preserved. In contrast to PruneAllButActive() this does
- // not update the session history of the RenderView.
- void PruneAllButActiveInternal();
+ // Removes all entries except the last committed entry. If there is a new
+ // pending navigation it is preserved. In contrast to PruneAllButVisible()
+ // this does not update the session history of the RenderView. Callers
+ // must ensure that |CanPruneAllButVisible| returns true before calling this.
+ void PruneAllButVisibleInternal();
// Returns true if the navigation is redirect.
bool IsRedirect(const ViewHostMsg_FrameNavigate_Params& params);
« no previous file with comments | « content/browser/android/content_view_core_impl.cc ('k') | content/browser/web_contents/navigation_controller_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698